@@ -126,39 +126,8 @@ def opcode_occurrence(opcode_list, collapse=0):
     - 2: Drop PUSH-like, DUP-like and SWAP-like opcodes, then replace all LOG-like opcodes with LOG.
     - 3: Drop all PUSH-like, DUP-like, SWAP-like and LOG-like opcodes.
     '''
-    stat_opcode_list = []
-
-    if collapse == 0:
-        stat_opcode_list = list(opcode_mapping.values())
-    elif collapse == 1:
-        for opcode in list(opcode_mapping.values()):
-            if 'PUSH' in opcode:
-                stat_opcode_list.append('PUSH')
-            elif 'DUP' in opcode:
-                stat_opcode_list.append('DUP')
-            elif 'SWAP' in opcode:
-                stat_opcode_list.append('SWAP')
-            elif 'LOG' in opcode:
-                stat_opcode_list.append('LOG')
-            else:
-                stat_opcode_list.append(opcode)
-    elif collapse == 2:
-        for opcode in list(opcode_mapping.values()):
-            if not (('PUSH' in opcode) or ('DUP' in opcode) or ('SWAP' in opcode)):
-                if 'LOG' in opcode:
-                    stat_opcode_list.append('LOG')
-                else:
-                    stat_opcode_list.append(opcode)
-            else:
-                pass
-    elif collapse == 3:
-        for opcode in list(opcode_mapping.values()):
-            if not (('PUSH' in opcode) or ('DUP' in opcode) or ('SWAP' in opcode) or ('LOG' in opcode)):
-                stat_opcode_list.append(opcode)
-            else:
-                pass
-    else:
-        raise ValueError('Parameter collapse can only be in [0, 1, 2, 3].')
+    
+    stat_opcode_list = collapse_opcode(opcode_list=opcode_list, collapse=collapse)
 
     occurrence_stat = dict.fromkeys(stat_opcode_list, 0)
     opcode_list = collapse_opcode(opcode_list, collapse)
